function [Model] = ImportGROWTHMATMod(filename,varargin)
%ImportGROWTHMATMod: Imports data from MAT.DAT model file generated by GROWTH
%and outputs Matlab volume data
%
% Inputs: filename = (string) full filename of MAT.DAT file (ex, 'MAT.DAT')
%         plotopt = (OPTIONAL, string) add a second argument 'plot' to display a 
%                   sample plot of data for confirmation.
%
% Outputs: Model = structure with the following fields:
%                  X = (volume data) x coordinates of data (utm,m)
%                  Y = (volume data) y coordinates of data (utm,m)
%                  Z = (volume data) z coordinates of data (m, elevation)
%                  DENS = (volume data) density at each point (kg/m^3)
%                  mtx_dimx = dimensions of volume data
%                  Emin = x min of data (utm,m)
%                  Emax = x max of data (utm,m)
%                  Nmin = y min of data (utm,m)
%                  Nmax = y max of data (utm,m)
%                  Dmin = z min of data (utm, elev)
%                  Dmax = z max of data (utm, elev)
%                  filename = (string) name of original input file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Patricia M., April 21, 2020
% Major edits:
% June 3, 2020: Changed second input argument to an optional argument
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


fid=fopen(filename,'r');

%get header info
header=fscanf(fid,'%f',9);

%get data
data=fscanf(fid,'%f');

%close file
fclose(fid);

%Define the matrix geometry
mtx=header(7:9)'; %read from MAT.dat file [rows, columns, pages] for mat1250

Emin= header(1);      % define minimum Easting
Emax= header(2);      % define maximum Easting

Nmin= header(3);      % define minimum Northing
Nmax= header(4);      % define maximum Northing

Dmin= header(5);      % define minimum Depth
Dmax= header(6);      % define maximim Depth

% define axis separation 
dE=(Emax-Emin)/(mtx(1)-1);
dN=(Nmax-Nmin)/(mtx(2)-1);
dD=(Dmax-Dmin)/(mtx(3)-1);

%Define axes
x=Emin:dE:Emax;
y=Nmin:dN:Nmax;
z=Dmin:dD:Dmax;

[X,Y,Z]=meshgrid(x,y,z);


%reshape data into volume data
data(data==9999)=NaN;
DENS=permute(reshape(data,mtx(2),mtx(1),mtx(3)),[2 1 3]);

% put stuff in output structure
Model.X=X;
Model.Y=Y;
Model.Z=Z;
Model.DENS=DENS;
Model.mtx_dim=mtx;
Model.Emin=Emin;
Model.Emax=Emax;
Model.Nmin=Nmin;
Model.Nmax=Nmax;
Model.Dmin=Dmin;
Model.Dmax=Dmax;
Model.filename=filename;

if ~isempty(varargin)&&strcmp(varargin{1},'plot')
    % preview plot
    figure;
    fv=isosurface(X,Y,Z,DENS,-100);hold on %define isosurface for given density contrast in kg/m3
    light
    p=patch(fv);
    set(p,'Facecolor', [.095,.14,.96], 'Edgecolor', 'none');
    material shiny
    lighting gouraud
    
    axis([650000 700000, 7500000 7560000, -10000 Dmax+2000])
    xlabel('Easting, m')
    ylabel('Northing, m')
    zlabel('Elevation, m')
    view(3)
end
end

